==> scriptsp-0.1.0.tgz: package/README.md <==
# scriptsp
Run multiple package.json scripts in parallel (for development)

# How to use it
install
```sh
$ npm install --save-dev scriptsp
```
package.json
```js
  ...
  "scripts": {
    "dev-server": "nodemon ....",
    "watch-test": "...some test watching script...",
    "watch-js": "watchify ...",

    "dev": "scriptsp dev-scripts",
    "dev-scripts": [
      "dev-server",
      "watch-test",
      "watch-js"
    ]
  }
  ...
```
run it
```sh
$ npm run dev
```

# License

The MIT License (MIT)

Copyright (c) 2015 Small Helm LLC

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> scriptsp-0.3.0.tgz: package/README.md <==
# scriptsp
Run multiple package.json scripts in parallel (for development)

# How to use it
install
```sh
$ npm install --save-dev scriptsp
```
package.json
```js
  ...
  "scripts": {
    "dev-server": "nodemon ....",
    "watch-test": "...some test watching script...",
    "watch-js": "watchify ...",

    "dev": "scriptsp dev-server watch-test watch-js"
  }
  ...
```
run it
```sh
$ npm run dev
```
![scriptsp demo](https://raw.githubusercontent.com/smallhelm/scriptsp/master/demo.png)

# License

The MIT License (MIT)

Copyright (c) 2015 Small Helm LLC

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
